@@ -9,16 +9,23 @@ import wgdi.base as base
 
 class karyotype_mapping():
     def __init__(self, options):
+        self.blast_reverse = 'False'
+        self.blockinfo_reverse = 'False'
         self.position = 'order'
+        self.block_length = 5
         self.limit_length = 5
+        self.repeat_number = 10
+        self.score = 100
+        self.evalue = 1e-5
         for k, v in options:
             setattr(self, str(k), v)
             print(str(k), ' = ', v)
 
     def karyotype_left(self, pairs, ancestor, gff1, gff2):
         for index, row in ancestor.iterrows():
+            (loc_min, loc_max) = sorted([row[1], row[2]])
             index1 = gff1[(gff1['chr'] == row[0]) & (
-                gff1['order'] >= row[1]) & (gff1['order'] <= row[2])].index
+                gff1['order'] >= loc_min) & (gff1['order'] <= loc_max)].index
             gff1.loc[index1, 'color'] = row[3]
             gff1.loc[index1, 'classification'] = row[4]
         data = pd.merge(pairs, gff1, left_on=0,
@@ -31,10 +38,12 @@ class karyotype_mapping():
 
     def karyotype_top(self, pairs, ancestor, gff1, gff2):
         for index, row in ancestor.iterrows():
+            (loc_min, loc_max) = sorted([row[1], row[2]])
             index1 = gff2[(gff2['chr'] == row[0]) & (
-                gff2['order'] >= row[1]) & (gff2['order'] <= row[2])].index
+                gff2['order'] >= loc_min) & (gff2['order'] <= loc_max)].index
             gff2.loc[index1, 'color'] = row[3]
             gff2.loc[index1, 'classification'] = row[4]
+        gff2.to_csv('out1.csv', sep='\t')
         data = pd.merge(pairs, gff2, left_on=1,
                         right_on=gff2.index, how='left')
         data.drop_duplicates(subset=[0], inplace=True)
@@ -73,7 +82,7 @@ class karyotype_mapping():
             ancestor.loc[group.index[0], 1] = 1
             ancestor.loc[group.index[-1], 2] = lens[chr]
         ancestor[4] = ancestor[4].astype(int)
-        return ancestor[[0,1,2,3,4]]
+        return ancestor[[0, 1, 2, 3, 4]]
 
     def colinear_gene_pairs(self, bkinfo, gff1, gff2):
         data = []
@@ -92,10 +101,52 @@ class karyotype_mapping():
         data = pd.DataFrame(data)
         return data
 
+    def new_ancestor(self, ancestor, gff1, gff2, blast):
+        for index, row in ancestor.iterrows():
+            if row[1] == 1:
+                chr_old = row[0]
+                color_old = row[3]
+                class_old = row[4]
+                area_mo = row[2]
+                continue
+            if (chr_old == row[0]) and (class_old == row[4]):
+                area = row[1]-area_mo
+                if area == 1:
+                    area_mo = row[2]
+                else:
+                    if hasattr(self, 'ancestor_top'):
+                        index1 = gff1[(gff1['chr'] == row[0]) & (
+                            gff1['order'] >= area_mo) & (gff1['order'] <= row[1])].index
+                        index2 = gff2[(gff2['color'] == color_old)].index
+                        index3 = gff2[(gff2['color'] == row[3])].index
+                    if hasattr(self, 'ancestor_left'):
+                        index1 = gff1[(gff1['chr'] == row[0]) & (
+                            gff1['order'] >= area_mo) & (gff1['order'] <= row[1])].index
+                        index2 = gff2[(gff2['color'] == color_old)].index
+                        index3 = gff2[(gff2['color'] == row[3])].index
+                    newblast1 = blast[(blast[0].isin(index1))
+                                      & (blast[1].isin(index2))]
+                    newblast2 = blast[(blast[0].isin(index1))
+                                      & (blast[1].isin(index3))]
+                    if len(newblast1) >= len(newblast2):
+                        ancestor.loc[index-1, 2] = row[1]-1
+                    else:
+                        ancestor.loc[index, 1] = area_mo+1
+            else:
+                chr_old = row[0]
+                color_old = row[3]
+                class_old = row[4]
+            area_mo = row[2]
+        return ancestor
+
     def run(self):
         bkinfo = pd.read_csv(self.blockinfo, index_col='id')
         bkinfo['chr1'] = bkinfo['chr1'].astype(str)
         bkinfo['chr2'] = bkinfo['chr2'].astype(str)
+        if self.blockinfo_reverse == True or self.blockinfo_reverse.upper() == 'TRUE':
+            bkinfo[['chr1', 'chr2']] = bkinfo[['chr2', 'chr1']]
+            bkinfo[['block1', 'block2']] = bkinfo[['block2', 'block1']]
+        bkinfo = bkinfo[bkinfo['length'] > int(self.block_length)]
         bkinfo['class1'] = ''
         bkinfo['col1'] = ''
         bkinfo['class2'] = ''
@@ -103,6 +154,12 @@ class karyotype_mapping():
         gff1 = base.newgff(self.gff1)
         gff2 = base.newgff(self.gff2)
         lens = base.newlens(self.the_other_lens, self.position)
+        blast = base.newblast(self.blast, int(self.score), float(
+            self.evalue), gff1, gff2, self.blast_reverse)
+        index = [group.sort_values(by=11, ascending=False)[:int(
+            self.repeat_number)].index.tolist() for name, group in blast.groupby([0])]
+        blast = blast.loc[np.concatenate(
+            np.array([k[:int(self.repeat_number)] for k in index], dtype=object)), [0, 1]]
         pairs = self.colinear_gene_pairs(bkinfo, gff1, gff2)
         data = []
         for k, v in lens.items():
@@ -120,5 +177,7 @@ class karyotype_mapping():
             ancestor = base.read_calassfication(self.ancestor_left)
             data = self.karyotype_left(pairs, ancestor, gff1, gff2)
         the_other_ancestor_file = self.karyotype_map(data, lens)
+        the_other_ancestor_file = self.new_ancestor(
+            the_other_ancestor_file, gff1, gff2, blast)
         the_other_ancestor_file .to_csv(
             self.the_other_ancestor_file, sep='\t', header=False, index=False)
